#!/usr/bin/env python

from utils import getColorChannel, Color
import os
from tqdm import tqdm
import numpy as np
from enum import Enum, auto

IMAGES_CAMERAS_FOLDER = {
    'RAISE': 'flat-field/nef',
    'Rafael 23/04/24': 'rafael/230424',
}

class Operation(Enum):
    LOAD_RAW = auto()
    SAVE = auto()
    LOAD_NPY = auto()

OPERATION = Operation.LOAD_RAW
RESOLUTION = 100
print(f'{OPERATION = }')
if OPERATION == Operation.LOAD_NPY:
    print(f'{RESOLUTION = }')

for camera in tqdm(IMAGES_CAMERAS_FOLDER, 'Camera'):
    imagesCameraFolder = IMAGES_CAMERAS_FOLDER[camera]
    for file in tqdm(os.listdir(imagesCameraFolder), 'Image'):
        if file.endswith('.NEF') or file.endswith('.ARW'):
            #print(file)
            imageFilePath = f'{imagesCameraFolder}/{file}'
            numpyFilePath = f'{imageFilePath}.npy'
            rawColorChannels = {}
            if OPERATION in [Operation.LOAD_RAW, Operation.SAVE]:
                for color in Color:
                    rawColorChannel = getColorChannel(imageFilePath, color)
                    rawColorChannels[color] = rawColorChannel
            if OPERATION == Operation.SAVE:
                np.save(numpyFilePath, rawColorChannels)
            if OPERATION == Operation.LOAD_NPY:
                rawColorChannels = np.load(numpyFilePath, allow_pickle = True)
                rawColorChannelsItem = rawColorChannels.item()
                for color in Color:
                    print(color, rawColorChannelsItem[color].mean())